@@ -113,4 +113,11 @@ test_that('partial name causes error', {
 test_that('trailing comma is accepted', {
     expect_error(box::use(mod/a, ), NA)
     expect_error(box::use(mod/a, mod/b, ), NA)
+    expect_error(box::use(mod/a[modname, double, ]), NA)
+})
+
+test_that('nested module can use parent', {
+    box::use(mod/b/b)
+    expect_true(exists('z', b))
+    expect_equal(b$z, 1)
 })
